@@ -39,8 +39,13 @@ class CondaEnvSpec:
         if not self.is_prefix:
             return self.name
         else:
+            # first directory part above ".venv", hopefully
             return first(
-                [p for p in reversed(Path(self.name).parts) if not p.startswith(".")]
+                [
+                    p
+                    for p in reversed(Path(self.name).resolve().parts)
+                    if not p.startswith(".")
+                ]
             )
 
 
